@@ -1,5 +1,6 @@
 from .logger import log
 from .api import GlobalObject
+from .utils.threading_utils import async_run
 
 # 创建全局可以访问且可序列化的对象
 g = GlobalObject()
@@ -7,5 +8,6 @@ g = GlobalObject()
 __all__ = [
     "log",
     "g",
-    "GlobalObject"
+    "GlobalObject",
+    "async_run"
 ]
