@@ -8,6 +8,9 @@ import getpass
 import pqsdk.utils.file_util as fu
 import json
 from .logger import log
+import logging
+
+log.set_level(logging.INFO)
 
 
 def input_with_default(prompt, default):
@@ -28,21 +31,26 @@ def handle_config_command():
         print("密码不能为空！")
         return
 
-    host = 'portal.tickertrading.com'
+    host = 'api.pinkquant.com'
 
     # 获取Tenant list
     url = f"http://{host}/api/admin/tenant/login/tenants?username={username}"
     response = requests.get(url)
     tenants = response.json()['data']
 
-    if len(tenants) > 0:
+    if len(tenants) == 0:
+        print(f"用户 {username} 未找到有效的协作空间, 请联系管理员")
+        return
+
+    if len(tenants) == 1:
+        # 仅归属一个协作空间
+        tenant_index = 0
+    else:
         print(f"用户 {username} 归属于如下的协作空间: \n")
         for index, tenant in enumerate(tenants):
             print(f"{index}: ", tenant['enterpriseName'])
-    else:
-        print(f"用户 {username} 未找到有效的协作空间, 请联系管理员")
 
-    tenant_index = input_with_default("\n请输入协作空间的编号(默认值为0): ", "0")
+        tenant_index = input_with_default("\n请输入协作空间的编号(默认值为0): ", "0")
 
     selectedTenant = tenants[int(tenant_index)]
     tenant_id = selectedTenant['tenantCode']
@@ -58,7 +66,12 @@ def handle_config_command():
         'Content-Type': 'application/x-www-form-urlencoded'
     }
     response = requests.post(url, params=params, headers=headers, data={"username": username, "password": password})
-    result = response.json()['data']
+    result = response.json()
+    if 'data' not in result:
+        log.error(f"用户未分配正确权限，请联系管理员")
+        return
+
+    result = result['data']
 
     config_file = 'config.sdk.json'
     if fu.check_path_exists(config_file):
@@ -68,6 +81,8 @@ def handle_config_command():
         sdk_config['token'] = result['access_token']
         sdk_config['audience'] = "api-client"
         sdk_config['host'] = host
+        with open(config_file, 'w', encoding='utf-8') as f:
+            json.dump(sdk_config, f)
         print("配件文件已经更新")
     else:
         # 创建配置文件
@@ -78,7 +93,7 @@ def handle_config_command():
         }
         with open(config_file, 'w', encoding='utf-8') as f:
             json.dump(data, f)
-        log.info("新的配置创建完成")
+        print("新的配置创建完成")
 
     # 检查响应状态码
     if response.status_code == 200:
