@@ -604,6 +604,18 @@ def get_abnormal_stocks(fields: list = None,
     return PQDataClient.instance().get_abnormal_stocks(**locals())
 
 
+@assert_auth
+def get_suspend_status(sec_code: str, trade_date: str = None):
+    """
+    合约停牌状态
+    :param sec_code:
+    :param trade_date:
+    :return: int
+            <=0 正常，-1 复牌，>0 停牌, >=1 停牌天数
+    """
+    return PQDataClient.instance().get_suspend_status(**locals())
+
+
 # ---------------------------------------------------------
 # 外部可以访问的列表
 # ---------------------------------------------------------
