@@ -692,7 +692,7 @@ class StrategyContext(AbstractStrategyContext):
                            "volume": "order_volume",
                            "price": "order_price"}, inplace=True)
 
-        if trade_date:
+        if not df.empty and trade_date is not None:
             df = df[df['trade_date'] == trade_date]
 
         if not df.empty:
@@ -918,6 +918,11 @@ class StrategyContext(AbstractStrategyContext):
         :param force: 如果force == True, 则直接交易，忽略是否进行委托队列。仅在实盘中有效, 在回测中忽略
         :return:
         """
+        # 检查股票是否已经停牌
+        if get_suspend_status(sec_code=stock_code, trade_date=self.current_dt.strftime('%Y-%m-%d')) > 0:
+            log.warning(f"股票停牌，取消买入: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
+            return
+
         # 获取价格
         if price_type != pqconstant.FIX_PRICE or price is None:
             # trade_date = self.current_dt.strftime('%Y-%m-%d')
@@ -936,7 +941,7 @@ class StrategyContext(AbstractStrategyContext):
                                    dividend_type=self.dividend_type,
                                    expect_df=True)
             if price_df.empty:
-                log.warning(f"股票停牌，取消买入: stock_code={stock_code}, trade_date={trade_date}")
+                log.warning(f"无法获取股票价格，取消买入: stock_code={stock_code}, trade_date={trade_date}")
                 return
             else:
                 price = price_df.iloc[0, 0]
@@ -985,6 +990,11 @@ class StrategyContext(AbstractStrategyContext):
         :param force:
         :return:
         """
+        # 检查股票是否已经停牌
+        if get_suspend_status(sec_code=stock_code, trade_date=self.current_dt.strftime('%Y-%m-%d')) > 0:
+            log.warning(f"股票停牌，取消卖出: stock_code={stock_code}, trade_date={self.current_dt.strftime('%Y-%m-%d')}")
+            return
+
         # 获取价格
         if price_type != pqconstant.FIX_PRICE or price is None:
             # trade_date = self.current_dt.strftime('%Y-%m-%d')
@@ -1003,7 +1013,7 @@ class StrategyContext(AbstractStrategyContext):
                                    dividend_type=self.dividend_type,
                                    expect_df=True)
             if price_df.empty:
-                log.warning(f"股票停牌，取消买入: stock_code={stock_code}, trade_date={trade_date}")
+                log.warning(f"无法获取股票价格，取消卖出: stock_code={stock_code}, trade_date={trade_date}")
                 return
             else:
                 price = price_df.iloc[0, 0]
