@@ -83,3 +83,15 @@ class Portfolio(AbstractPortfolio):
         :return:
         """
         self._cash = self._cash + cash
+
+    def get_frozen_cash(self, sec_code: str = None):
+        """
+        获取冻结现金
+        冻结现金 = sum（（买入委托数量 - 买入成交数量） * 委托价格）
+
+        在回测过程中，买入委托即刻成交，所以冻结现金默认为0
+
+        :param sec_code: 获取指定股票的冻结现金, 如果为None，则获取投资组合的冻结现金
+        :return:
+        """
+        return 0
