@@ -1,14 +1,14 @@
-import pqsdk.faxconstant as faxconstant
 from enum import Enum
+from pqsdk import pqconstant
 
 
 class OrderStatus(Enum):
     # 排队的委托：代办
-    queue_pending = faxconstant.QUEUED_ORDER_STATUS_PENDING
+    queue_pending = pqconstant.QUEUED_ORDER_STATUS_PENDING
     # 排队的委托：已报，委托到券商
-    queue_reported = faxconstant.QUEUED_ORDER_STATUS_REPORTED
+    queue_reported = pqconstant.QUEUED_ORDER_STATUS_REPORTED
     # 排队的委托：已撤，从队列中撤销
-    queue_canceled = faxconstant.QUEUED_ORDER_STATUS_CANCELED
+    queue_canceled = pqconstant.QUEUED_ORDER_STATUS_CANCELED
 
     # 订单新创建未委托，用于盘前/隔夜单，订单在开盘时变为 open 状态开始撮合
     new = 8
