@@ -86,16 +86,27 @@ class AbstractStrategyContext(with_metaclass(abc.ABCMeta)):
         """
         raise NotImplementedError
 
-    # @abc.abstractmethod
-    # def run_every_minutes(self, func: Callable, minutes: int) -> None:
-    #     """
-    #     每n分钟执行任务
-    #
-    #     :param func: 一个自定义的函数, 此函数必须接受context参数;例如自定义函数名market_open(context)
-    #     :param minutes: 每n分钟执行任务
-    #     :return:
-    #     """
-    #     raise NotImplementedError
+    @abc.abstractmethod
+    def run_minutely(self, func: Callable, time_str: str, minutes: int = 1) -> None:
+        """
+        每天内何时开始，间隔n分钟执行
+
+        :param func: 一个自定义的函数, 此函数必须接受context参数;例如自定义函数名market_open(context)
+        :param time_str: 具体执行时间,一个字符串格式的时间, 24小时内的任意时间，例如"10:00", "01:00"；
+        :param minutes: 间隔执行的分钟数
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def run_secondly(self, func: Callable, time_str: str, seconds: int = 1) -> None:
+        """
+        每天内何时开始，间隔n秒执行
+
+        :param func: 一个自定义的函数, 此函数必须接受context参数;例如自定义函数名market_open(context)
+        :param time_str: 具体执行时间,一个字符串格式的时间, 24小时内的任意时间，例如"10:00", "01:00"；
+        :param seconds: 间隔执行的秒数
+        """
+        raise NotImplementedError
 
     @abc.abstractmethod
     def cancel(self, order, force: bool = False):
@@ -117,27 +128,6 @@ class AbstractStrategyContext(with_metaclass(abc.ABCMeta)):
         """
         raise NotImplementedError
 
-    # @abc.abstractmethod
-    # def get_positions_plan(self) -> dict:
-    #     """
-    #     获取策略执行当日（调仓日）的调仓信号。
-    #     回测模块：从回测持仓计划表获取
-    #     实盘模块：从因子组合中实时计算
-    #
-    #     :return: {'600036.SH': {'volume': 200, 'value': None, 'weight': None},
-    #               '601668.SH': {'volume': 200, 'value': None, 'weight': None})
-    #     """
-    #     raise NotImplementedError
-
-    # @abc.abstractmethod
-    # def get_market_data(self, stock_code: str):
-    #     """
-    #     获取行情数据
-    #     :param stock_code: 股票代码
-    #     :return:
-    #     """
-    #     raise NotImplementedError
-
     @abc.abstractmethod
     def get_current_data(self):
         """
@@ -554,3 +544,154 @@ class AbstractStrategyContext(with_metaclass(abc.ABCMeta)):
         :return:
         """
         raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_last_ticks(self, sec_code_lst: list, index: bool = False, fields: list = None):
+        """
+        获取当前最新的Tick数据。
+        注意：不是历史某个回测时间点的Tick数据。
+
+        :param sec_code_lst:
+        :param fields: 返回的字段列表
+        :param index: 是否设置sec_code为Index
+        :return:
+                [{
+                'sec_code', 股票代码
+                ’datetime'  tick时间字符串： %Y-%m-%d %H:%M:%S
+                'open', 当日开盘价
+                'high', 当日收盘价
+                'low', 当日最低价
+                'last_price', 当日最新价格
+                'pre_close', 昨日收盘价
+                'volume', 当日成交量，单位：手
+                'amount', 当日成交额
+                }]
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_plate_data(self, trade_date: str = None, end_time: str = "15:00", limit: int = 3) -> pd.DataFrame:
+        """
+        获取板块列表
+
+        :param trade_date: 指定交易日的板块列表
+        :param end_time: 指定板块排名的时间节点，从09:25开始到15:30结束，每个间隔5分钟
+        :param limit: 按照板块强度倒序排名的板块数量
+        :return:
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_plate_members_lst(self, plate_code_list: list, trade_date: str = None):
+        """
+        获取板块的成分股
+        :param plate_code_list:
+        :param trade_date:
+        :return:
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_stock_name(self, sec_code: str, trade_date: str = None):
+        """
+        获取股票代码的最新名称
+
+        :param sec_code:
+        :param trade_date:
+            None：默认为当天，如果当天不是交易日，则获取上一个交易日。
+            'YYYY-mm-dd'：具体日期的最新股票名称
+        :return: 股票名称
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_stock_price(self,
+                        sec_code: str,
+                        trade_date: str = None,
+                        end_time: str = None,
+                        dividend_type: str = "front"):
+        """
+        获取最新的股票价格
+
+        :param dividend_type: 复权选项(对股票/基金的价格字段、成交量字段及factor字段生效)
+                    'front'
+                    : 前复权, 默认是前复权
+                    none
+                    : 不复权, 返回实际价格
+                    'back'
+                    : 后复权
+        :param trade_date: 指定交易日, 格式: 2024-07-15
+        :param end_time: 如果trade_date不是系统日期当日，可以指定历史数据的具体分钟，格式：09:30
+        :param sec_code:
+        :return:
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_price_limit(self,
+                        sec_code: str,
+                        trade_date: str = None,
+                        dividend_type: str = "front"):
+        """
+        股票代码涨跌停价格
+        假设：
+        - 600xxx, 601xxx, 603xxx：上海主板，涨跌停限制10%
+        - 000xxx：深圳主板，涨跌停限制10%
+        - 002xxx：深圳中小板，涨跌停限制10%
+        - 300xxx：深圳创业板，涨跌停限制20%
+        - 688xxx：上海科创板，涨跌停限制20%
+
+        :param dividend_type: 复权选项(对股票/基金的价格字段、成交量字段及factor字段生效)
+                    'front'
+                    : 前复权, 默认是前复权
+                    none
+                    : 不复权, 返回实际价格
+                    'back'
+                    : 后复权
+        :param sec_code:
+        :param trade_date: 指定日期的涨跌停价格
+        :return: (昨日收盘价格, 今日涨停价, 今日跌停价)
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_auction_data(self,
+                         security: str,
+                         count: int = None,
+                         unit: str = '1m',
+                         trade_date: str = None,
+                         start_datetime: str = None,
+                         end_datetime: str = None,
+                         fields=None):
+        """
+        获取股票的集合竞价数据。
+
+        :param security: 股票代码
+        :param count: 返回行数
+        :param unit: 支持1m, 5m
+        :param trade_date: 交易日
+        :param start_datetime: 开始时间
+        :param end_datetime: 结束时间
+        :param fields: 获取字段，范围：['open', 'high', 'low', 'close', 'pre_close']
+        :return:
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def get_orders(self, trade_date: str = None, is_buy: bool = None, include_canceled: bool = True):
+        """
+        获取交易日的委托单，返回DataFrame
+
+        :param include_canceled: 是否包括已撤的委托
+        :param trade_date:
+        :param is_buy:
+        :return: DataFrame,
+            字段：['order_code', 委托编号
+                'sec_code',  股票代码
+                'order_time', 委托时间
+                'is_buy', 委托买卖方向：买单=1， 卖单=0
+                'order_volume',  委托数量
+                'order_price']  委托价格
+        """
+        raise NotImplementedError
+
